@@ -10,5 +10,5 @@ class LinkedLoader(SafeLoader):
     yaml_constructors = {
         **SafeLoader.yaml_constructors.copy(),
         "!@": LinkedTag.from_yaml,
-        "": _CustomScalarNode.from_yaml
+        "": _CustomScalarNode.from_yaml,
     }
