@@ -23,7 +23,8 @@ class LinkedTag(CustomTag):
         else:
             raise requests.HTTPError(
                 f"Failed to retrieve linked YAML document. "
-                f"{response.status_code}: {response.content}")
+                f"{response.status_code}: {response.content}"
+            )
 
     @classmethod
     def from_yaml(cls, loader: SafeLoader, node: ScalarNode) -> Text:
@@ -36,7 +37,6 @@ class LinkedTag(CustomTag):
 
         else:
             with open(node.value) as target:
-                print(target)
                 data = load(target, Loader=Loader)
 
         return data
